package com.vendor.loader.util;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.loader.Log.Log;
import com.vendor.loader.Messages;
import com.vendor.loader.util.ConvertUtils;
import com.vendor.loader.util.StringUtil;
import java.math.BigInteger;
import java.util.ArrayList;
import org.eclipse.osgi.util.NLS;

public class PropertiesUtility {
  public static final String DEVICE_SETTING_FOLDER = "Resources/Common/ChipProperties/";
  
  public static final int GET_INT_VALUE_ERROR = -1;
  
  public static final String INI = "INI";
  
  public static final String XML = "XML";
  
  public static final String KEY_CHIPNAME = "ChipName";
  
  public static final String KEY_XMLPATH = "Path";
  
  public static final String SOCT_OTA_CONFIG = "soctota.config";
  
  public static final String SOCT_FILE_CONFIG = "soctfile.config";
  
  public static final String SSU_OTA_CONFIG = "ssuota.config";
  
  public static final String GROUPID = "GroupID";
  
  public static final String SAMPLE = "sample";
  
  public static final String CONFIG = "config";
  
  protected static final String PID = "PID";
  
  protected static final String TABLE_ID = "TableID";
  
  protected static final String MANUFACTURER_ID = "ManufacturerID";
  
  protected static final String HARDWARE_VERSION = "HardwareVersion";
  
  protected static final String SOFTWARE_VERSION = "SoftwareVersion";
  
  protected static final String START_SEQUENCE_NUM = "StartSequenceNumber";
  
  protected static final String END_SEQUENCE_NUM = "EndSequenceNumber";
  
  protected static final String CONTORL_INFO_INSERTION_FREQUENCY = "ControlInformationInsertionFrequency";
  
  protected static final String INSERT_LINK_DESCRIPTOR = "InsertLinkDescriptor";
  
  protected static final String INSERT_EMPTY_PACKET = "InsertEmptyPacket";
  
  protected static final String UPGRADE_MODE = "UpgradeMode";
  
  protected static final String SYMBOL_RATE_OF_UPGRADE_STREAM = "SymbolRateOfUpgradeStream";
  
  protected static final String TRANSFER_MODE = "TransferMode";
  
  protected static final String CABLE_MODULATION_MODE = "CableModulationMode";
  
  protected static final String CABLE_FREQUENCY_MODE = "CableFrequency";
  
  protected static final String BANDWIDTH = "BandWidth";
  
  protected static final String CENTER_FREQUENCY = "CenterFrequency";
  
  protected static final String CONSTELLATION = "Constellation";
  
  protected static final String SYMBOL_RATE_OF_UPGRADE_STREAM_FOR_EMPTY = "SymbolRateOfUpgradeStreamForEmpty";
  
  protected static final String SYMBOL_RATE_OF_VAILD_DATA = "SymbolRateOfVaildData";
  
  protected static final String GROUP_ID_MIN = "0x2";
  
  protected static final String GROUP_ID_MAX = "0xFFFF";
  
  protected static final String PID_MIN = "0x20";
  
  protected static final String PID_MAX = "0x1FFE";
  
  protected static final String TABLEID_MIN = "0x40";
  
  protected static final String TABLEID_MAX = "0xFF";
  
  protected static final String MANUFACTYRERID_MIN = "0x0000";
  
  protected static final String MANUFACTYRERID_MAX = "0xFFFF";
  
  protected static final String HARDWARE_VERSION_MIN = "0x00";
  
  protected static final String HARDWARE_VERSION_MAX = "0xFFFFFFFF";
  
  protected static final String SOFTWARE_VERSION_MIN = "0x00000000";
  
  protected static final String SOFTWARE_VERSION_MAX = "0xFFFFFFFF";
  
  protected static final String START_SN_MIN = "0x00000000";
  
  protected static final String START_SN_MAX = "0xFFFFFFFF";
  
  protected static final String END_SN_MIN = "0x00000000";
  
  protected static final String END_SN_MAX = "0xFFFFFFFF";
  
  private ArrayList<UDProperty> properties = new ArrayList<>();
  
  private static boolean isCmdLine = false;
  
  public static boolean isCmdLine() {
    return isCmdLine;
  }
  
  public static void setCmdLine(boolean isCmdLine) {
    com.vendor.loader.util.PropertiesUtility.isCmdLine = isCmdLine;
  }
  
  protected boolean checkParamValue(String paramName, String minValueStr, String maxValueStr) {
    String paramNameStr = queryForString(paramName);
    try {
      if (paramNameStr != null) {
        if (!StringUtil.hexInRange(paramNameStr, minValueStr, maxValueStr)) {
          Log.showError(
              NLS.bind(Messages.MESSAGE_PARAMETER_OUT_OF_RANGE, (Object[])new String[] { paramName, minValueStr, maxValueStr }));
          return false;
        } 
      } else {
        Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, paramName));
        return false;
      } 
    } catch (NumberFormatException e) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_Invalid, paramName));
      return false;
    } 
    if (paramName.equalsIgnoreCase("CenterFrequency")) {
      BigInteger v = StringUtil.toBigInteger(paramNameStr);
      if (v.intValue() % 10 == 0)
        return true; 
      Log.errorln(Messages.MESSAGE_MUTIPLE_OF_10);
      return false;
    } 
    return true;
  }
  
  protected UDProperty get(String key) {
    for (UDProperty prop : this.properties) {
      if (key.equals(prop.getKey()))
        return prop; 
    } 
    return null;
  }
  
  public void set(String key, String value) {
    UDProperty prop = get(key);
    if (prop != null) {
      prop.setValue(value);
    } else {
      this.properties.add(new UDProperty(key, value));
    } 
  }
  
  public String queryForString(String key) {
    UDProperty prop = get(key);
    if (prop != null)
      return prop.getValue(); 
    return null;
  }
  
  public Integer queryForInteger(String key) {
    UDProperty prop = get(key);
    if (prop != null) {
      int rtValue;
      try {
        if (prop.getValue().toLowerCase().startsWith("0x")) {
          Long tmpNum = Long.valueOf(Long.parseLong(prop.getValue().substring(2), 16));
          rtValue = tmpNum.intValue();
        } else {
          rtValue = Integer.parseInt(prop.getValue());
        } 
      } catch (NumberFormatException e) {
        return null;
      } 
      return Integer.valueOf(rtValue);
    } 
    return null;
  }
  
  public double queryForDouble(String key) {
    UDProperty prop = get(key);
    if (prop != null) {
      double rtValue;
      try {
        Double tmpNum = Double.valueOf(Double.parseDouble(prop.getValue()));
        rtValue = tmpNum.intValue();
      } catch (NumberFormatException e) {
        return -1.0D;
      } 
      return rtValue;
    } 
    return -1.0D;
  }
  
  public Long queryForLong(String key) {
    UDProperty prop = get(key);
    if (prop != null) {
      long rtValue;
      try {
        if (prop.getValue().toLowerCase().startsWith("0x")) {
          rtValue = Long.parseLong(prop.getValue().substring(2), 16);
        } else {
          rtValue = Long.parseLong(prop.getValue());
        } 
      } catch (NumberFormatException e) {
        return null;
      } 
      return Long.valueOf(rtValue);
    } 
    return null;
  }
  
  protected boolean getParamBoolValue(String keyName, String fileName) {
    String keyValueStr = queryForString(keyName);
    if (keyValueStr != null && !keyValueStr.isEmpty())
      try {
        boolean result = ConvertUtils.stringToBoolean(keyValueStr);
        return result;
      } catch (NumberFormatException e) {
        Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_INPUT, keyName, fileName));
        return false;
      }  
    Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_INPUT, keyName, fileName));
    return false;
  }
}
